# -*- coding: utf-8 -*-
# Generated by Django 1.11.5 on 2017-09-19 18:56
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('song', '0002_add_duration'),
    ]

    operations = [
        migrations.AddField(
            model_name='song',
            name='upload',
            field=models.FileField(default='', upload_to='songs'),
            preserve_default=False,
        ),
    ]
